@@ -267,9 +267,6 @@ void              nautilus_icon_container_end_loading                   (Nautilu
 gboolean          nautilus_icon_container_is_auto_layout                (NautilusIconContainer  *container);
 void              nautilus_icon_container_set_auto_layout               (NautilusIconContainer  *container,
 									 gboolean                auto_layout);
-gboolean          nautilus_icon_container_is_tighter_layout             (NautilusIconContainer  *container);
-void              nautilus_icon_container_set_tighter_layout            (NautilusIconContainer  *container,
-									 gboolean                tighter_layout);
 
 gboolean          nautilus_icon_container_is_keep_aligned               (NautilusIconContainer  *container);
 void              nautilus_icon_container_set_keep_aligned              (NautilusIconContainer  *container,
